outliers: Extracts Outliers
Description
Extracts outliers from object of class "outForest".
The outliers are sorted by their absolute score in descending fashion.
Usage
outliers(object, ...)# S3 method for default
outliers(object, ...)
# S3 method for outForest
outliers(object, ...)
Value
A data.frame with one row per outlier. The columns are as follows:
row, col: Row and column in original data with outlier.
observed: Observed value.
predicted: Predicted value.
rmse: Scaling factor used to normalize the difference between observed
and predicted.
score: Outlier score defined as (observed-predicted)/RMSE.
threshold: Threshold above which an outlier score counts as outlier.
replacement: Value used to replace observed value.
Arguments
- object
An object of class "outForest".
- ...
Arguments passed from or to other methods.
Examples
Run this codex <- outForest(iris)
outliers(x)
Run the code above in your browser using DataLab